@@ -3,5 +3,11 @@
 from .single_cell_features import SingleCellFeatures
 from .single_cell_images import SingleCellImages
 from .standardize_fov_array import StandardizeFOVArray
+from .make_diagnostic_sheet import MakeDiagnosticSheet
 
-__all__ = ["SingleCellFeatures", "StandardizeFOVArray", "SingleCellImages"]
+__all__ = [
+    "SingleCellFeatures",
+    "StandardizeFOVArray",
+    "SingleCellImages",
+    "MakeDiagnosticSheet",
+]
